
Linux eduVPN client and Python API
==================================

This is the GNU/Linux desktop client for eduVPN. It also is a Python client API.

Read more about eduVPN on the eduVPN website http://eduvpn.org/.

Installation
============

Read the installation instructions [here](http://python-eduvpn-client.readthedocs.io/en/latest/introduction.html#installation).

Documentation
=============

You can find the documentation on [http://python-eduvpn-client.readthedocs.io](http://python-eduvpn-client.readthedocs.io).

Development
===========

[![Build Status](https://travis-ci.org/eduvpn/python-eduvpn-client.svg?branch=master)](https://travis-ci.org/eduvpn/python-eduvpn-client)
